@@ -11,6 +11,7 @@ from .api.http_api_generator import HttpApiGenerator
 from .packagetype import ZIP, IMAGE
 from .s3_utils.uri_parser import construct_s3_location_object, construct_image_code_object
 from .tags.resource_tagging import get_tag_list
+from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.model import PropertyType, SamResourceMacro, ResourceTypeResolver
 from samtranslator.model.apigateway import (
     ApiGatewayDeployment,
@@ -122,6 +123,7 @@ class SamFunction(SamResourceMacro):
         except InvalidEventException as e:
             raise InvalidResourceException(self.logical_id, e.message)
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         """Returns the Lambda function, role, and event resources to which this SAM Function corresponds.
 
@@ -155,6 +157,11 @@ class SamFunction(SamResourceMacro):
             code_sha256 = None
             if self.AutoPublishCodeSha256:
                 code_sha256 = intrinsics_resolver.resolve_parameter_refs(self.AutoPublishCodeSha256)
+                if not isinstance(code_sha256, string_types):
+                    raise InvalidResourceException(
+                        self.logical_id,
+                        "AutoPublishCodeSha256 must be a string",
+                    )
             lambda_version = self._construct_version(
                 lambda_function, intrinsics_resolver=intrinsics_resolver, code_sha256=code_sha256
             )
@@ -882,6 +889,7 @@ class SamApi(SamResourceMacro):
         "ApiKey": ApiGatewayApiKey.resource_type,
     }
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         """Returns the API Gateway RestApi, Deployment, and Stage to which this SAM Api corresponds.
 
@@ -989,6 +997,7 @@ class SamHttpApi(SamResourceMacro):
         "DomainName": ApiGatewayV2DomainName.resource_type,
     }
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         """Returns the API GatewayV2 Api, Deployment, and Stage to which this SAM Api corresponds.
 
@@ -1061,6 +1070,7 @@ class SamSimpleTable(SamResourceMacro):
     }
     attribute_type_conversions = {"String": "S", "Number": "N", "Binary": "B"}
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         dynamodb_resources = self._construct_dynamodb_table()
 
@@ -1125,6 +1135,7 @@ class SamApplication(SamResourceMacro):
         "TimeoutInMinutes": PropertyType(False, is_type(int)),
     }
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         """Returns the stack with the proper parameters for this application"""
         nested_stack = self._construct_nested_stack()
@@ -1176,6 +1187,7 @@ class SamLayerVersion(SamResourceMacro):
     DELETE = "Delete"
     retention_policy_options = [RETAIN.lower(), DELETE.lower()]
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         """Returns the Lambda layer to which this SAM Layer corresponds.
 
@@ -1332,6 +1344,7 @@ class SamStateMachine(SamResourceMacro):
         samtranslator.model.stepfunctions.events,
     )
 
+    @cw_timer
     def to_cloudformation(self, **kwargs):
         managed_policy_map = kwargs.get("managed_policy_map", {})
         intrinsics_resolver = kwargs["intrinsics_resolver"]
